/**
 * JASMINe
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RemovePurgeTaskCommand.as 5941 2010-01-15 15:41:04Z fornacif $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.datamanagement.command
{	
    import com.adobe.cairngorm.commands.ICommand;
    import com.adobe.cairngorm.control.CairngormEvent;
    import com.adobe.cairngorm.control.CairngormEventDispatcher;
    
    import mx.collections.ArrayCollection;
    
    import mx.rpc.IResponder;
    import mx.rpc.events.FaultEvent;
    import mx.rpc.events.ResultEvent;
    
    import org.ow2.jasmine.monitoring.eos.common.controls.ServerSideException;
    import org.ow2.jasmine.monitoring.eos.common.events.ServerSideExceptionEvent;
    import org.ow2.jasmine.monitoring.eos.datamanagement.business.*;
    import org.ow2.jasmine.monitoring.eos.datamanagement.model.*;
    import org.ow2.jasmine.monitoring.eos.datamanagement.event.RemovePurgeTaskEvent;
    
    import org.ow2.jasmine.monitoring.eos.datamanagement.vo.*;
    
    [Event(name="serverSideException", type="org.ow2.jasmine.monitoring.eos.common.events.ServerSideExceptionEvent")]
    public class RemovePurgeTaskCommand implements ICommand, IResponder
    {
        /**
         * Retrieve the delegate and use it to get the notifs.
         * @author Francois Fornaciari
         */
        public function execute(event:CairngormEvent):void
        {
            var delegate:IRemovePurgeTaskDelegate = DataManagementModelLocator.getInstance().getRemovePurgeTaskDelegate();
            delegate.responder = this;
            delegate.removePurgeTask((event as RemovePurgeTaskEvent).purgeTaskId);
        }
        
        /**
         * Push the notifs into the model.
         */
        public function result(data:Object):void
        {
            var model:DataManagementModelLocator = DataManagementModelLocator.getInstance();
            var purgeTaskId:Number = (data as ResultEvent).result as Number;
            model.removePurgeTask(purgeTaskId);     
        }
        
        /**
         * Raise an alert when something is wrong.
         */
        public function fault(info:Object):void
        {
            // Retrieve the fault event
            var faultEvent : FaultEvent = FaultEvent(info);
            
            // Tell the view and let it handle this
            var serverSideExceptionEvent : ServerSideExceptionEvent =
                new ServerSideExceptionEvent(
                    "serverSideException",
                    new ServerSideException("Error while Executing the action",
                        "The operation could not be performed."
                        + "\n" + faultEvent.fault.faultCode
                        + "\n" + faultEvent.fault.faultString,
                        faultEvent.fault.getStackTrace()));
            CairngormEventDispatcher.getInstance().dispatchEvent(serverSideExceptionEvent);
            
        }
        
    }
}
